/******************************
 * The Fredericks Company
 * www.frederickscompany.com
 * sales@frederickscompany.com
 *
 * SPI Arduino Communication
 * 
 * Code for Arduino Uno to read tilt and temperature from
 * a sensor mounted on the 1-6200-005 signal conditioner
 * using an SPI signal.
 * 
 * Output: print X, Y, and Temperature to serial port every 1 second
 *
 * Rev -
 * 
 * */

#include <SPI.h>

#define SS1 10

void setup() {
    Serial.begin(9600); // set the baud rate for the Arduino serial communication
    SPI.begin(); // initialize SPI
    SPI.setClockDivider(SPI_CLOCK_DIV8); // Set clock frequency
    digitalWrite(SS1, HIGH); // disable slave 1
    Serial.println("setup complete");
}

void loop() {
    byte res, hi, lo; // define res, hi, & low variables
    unsigned int x, y, temperature; // define x, y, & temperature variables

    // open SPI communication
    SPI.beginTransaction(SPISettings(20000000, MSBFIRST, SPI_MODE3));
    digitalWrite(10, LOW); // enable the slave controlled by D10

    SPI.transfer(0x39); // request status
    delay(10); // wait for SPI response
    res = SPI.transfer(0x31); // get status, request high x byte
    delay(10); // wait for SPI response

    if (res == 0x2A) {
        hi = SPI.transfer(0x32); // get high x byte, request low x byte
        delay(1); // wait for SPI response
        lo = SPI.transfer(0x33); // get low x byte, request high y byte
        x = (hi << 8) | lo; // merge low and high bytes into int

        delay(1); // wait for SPI response
        hi = SPI.transfer(0x34); // get high y byte, request low y byte
        delay(1); // wait for SPI response
        lo = SPI.transfer(0x35); // get low y byte, request high temperature byte
        y = (hi << 8) | lo; // merge low and high bytes into int

        delay(1); // wait for SPI response
        hi = SPI.transfer(0x36); // get high temperature byte, request low temperature byte
        delay(1); // wait for SPI response
        lo = SPI.transfer(0x39); // get low temperature byte
        temperature = (hi << 8) | lo; // merge low and high bytes into int

        char out[50]; // define a char array to store the output
        sprintf(out, "X: %u\nY: %u\nT: %u\n", x, y, temperature); // assemble the output
        Serial.println(out); // print the output to the Serial Monitor
    }

    digitalWrite(10, HIGH); // disable the slave controlled by D10
    SPI.endTransaction(); // close the SPI communication

    delay(1000);
}